# Creating Category Hierarchies
      
Adding structure to a glossary can be useful - especially as glossaries increase in size. We have already shown
how glossary terms can be assigned to categories, and categories to glossaries. Sometimes we need even more structure.
So in Egeria, we can build hierarchies of categories where any given category can be assigned a parent. Let's give this
a try.

First, we'll create a new category called 

___

# Create Category  
  
## Category Name  
  
Dr.Egeria Actions
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  
  
## Description  
  
The actions that Dr. Egeria can process.
  
  
## <Qualified Name>  
  
## <GUID>  

___

# Create Category  
  
## Category Name  
  
Command Attributes
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  
  
## Description  
  
Common attributes of commands
   
___

# Create Category  
  
## Category Name  
  
Dr.Egeria Verbs
  
## Owning Glossary  
  
Glossary::Egeria-Markdown  
  
## Description  

Kinds of actions Dr.Egeria can take.

# Set Parent Category

## Parent Category
Writing Dr.Egeria Markdown

## Child Category
  
Dr.Egeria Actions

___
   

# Set Parent Category

## Parent Category
Writing Dr.Egeria Markdown

## Child Category
  
Dr.Egeria Verbs

___

# Set Parent Category

## Parent Category
Writing Dr.Egeria Markdown

## Child Category
  
Dr. Egeria Commands 
___